# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V18::Enums::AppBiddingGoalEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                            => "UNSPECIFIED",
  UNKNOWN                                => "UNKNOWN",
  OPTIMIZE_FOR_INSTALL_CONVERSION_VOLUME =>
    "OPTIMIZE_FOR_INSTALL_CONVERSION_VOLUME",
  OPTIMIZE_FOR_IN_APP_CONVERSION_VOLUME =>
    "OPTIMIZE_FOR_IN_APP_CONVERSION_VOLUME",
  OPTIMIZE_FOR_TOTAL_CONVERSION_VALUE => "OPTIMIZE_FOR_TOTAL_CONVERSION_VALUE",
  OPTIMIZE_FOR_TARGET_IN_APP_CONVERSION =>
    "OPTIMIZE_FOR_TARGET_IN_APP_CONVERSION",
  OPTIMIZE_FOR_RETURN_ON_ADVERTISING_SPEND =>
    "OPTIMIZE_FOR_RETURN_ON_ADVERTISING_SPEND",
  OPTIMIZE_FOR_INSTALL_CONVERSION_VOLUME_WITHOUT_TARGET_CPI =>
    "OPTIMIZE_FOR_INSTALL_CONVERSION_VOLUME_WITHOUT_TARGET_CPI",
  OPTIMIZE_FOR_PRE_REGISTRATION_CONVERSION_VOLUME =>
    "OPTIMIZE_FOR_PRE_REGISTRATION_CONVERSION_VOLUME"
];

1;
